@@ -1,37 +1,28 @@
 <?php
 /**
- * GForge Project Management Facility
+ * FusionForge project manager
  *
- * Copyright 2002 GForge, LLC
- * http://gforge.org/
+ * Copyright 1999-2000, Tim Perdue/Sourceforge
+ * Copyright 2002, Tim Perdue/GForge, LLC
+ * Copyright 2009, Roland Mas
  *
- * @version   $Id$
+ * This file is part of FusionForge.
  *
- * This file is part of GForge.
- *
- * GForge is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * GForge is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * FusionForge is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published
+ * by the Free Software Foundation; either version 2 of the License,
+ * or (at your option) any later version.
+ * 
+ * FusionForge is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GForge; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  US
+ * along with FusionForge; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
  */
-/*
-
-	Project/Task Manager
-	By Tim Perdue, Sourceforge, 11/99
-	Heavy rewrite by Tim Perdue April 2000
-
-	Total rewrite in OO and GForge coding guidelines 12/2002 by Tim Perdue
-*/
-
 
 require_once $gfcommon.'include/Error.class.php';
 require_once $gfcommon.'include/Validator.class.php';
@@ -42,8 +33,8 @@ function &projecttask_get_object($project_task_id,$data=false) {
 			if ($data) {
 				//the db result handle was passed in
 			} else {
-				$res=db_query("SELECT * FROM project_task_vw
-					WHERE project_task_id='$project_task_id'");
+				$res = db_query_params ('SELECT * FROM project_task_vw WHERE project_task_id=$1',
+							array ($project_task_id)) ;
 
 				if (db_numrows($res) <1 ) {
 					$PROJECTTASK_OBJ["_".$project_task_id."_"]=false;
@@ -203,7 +194,8 @@ class ProjectTask extends Error {
 			$this->data_array['project_task_id']=$project_task_id;
 
 		} else {
-			$res=db_query("SELECT nextval('project_task_pk_seq') AS id");
+			$res = db_query_params ('SELECT nextval($1) AS id', 
+						array ('project_task_pk_seq'));
 			if (!$project_task_id=db_result($res,0,'id')) {
 				$this->setError( 'Could Not Get Next Project Task ID' );
 				db_rollback();
@@ -212,12 +204,22 @@ class ProjectTask extends Error {
 
 			$this->data_array['project_task_id']=$project_task_id;
 
-			$sql="INSERT INTO project_task (project_task_id,group_project_id,created_by,summary,
-					details,start_date,end_date,status_id,category_id,priority,percent_complete,hours,duration,parent_id) 
-					VALUES ('$project_task_id','". $this->ProjectGroup->getID() ."', '".user_getid()."', '". htmlspecialchars($summary) ."',
-					'". htmlspecialchars($details) ."','$start_date','$end_date','1','$category_id','$priority','$percent_complete','$hours','$duration','$parent_id')";
+			$result = db_query_params ('INSERT INTO project_task (project_task_id,group_project_id,created_by,summary,details,start_date,end_date,status_id,category_id,priority,percent_complete,hours,duration,parent_id) VALUES ($1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14)',
+						   array ($project_task_id,
+							  $this->ProjectGroup->getID(),
+							  user_getid(),
+							  htmlspecialchars($summary),
+							  htmlspecialchars($details),
+							  $start_date,
+							  $end_date,
+							  1,
+							  $category_id,
+							  $priority,
+							  $percent_complete,
+							  $hours,
+							  $duration,
+							  $parent_id)) ;
 
-			$result=db_query($sql);
 			if (!$result || db_affected_rows($result) < 1) {
 				$this->setError('ProjectTask::create() Posting Failed '.db_error().$sql);
 				db_rollback();
@@ -249,9 +251,11 @@ class ProjectTask extends Error {
 	 *  @return	boolean	success.
 	 */
 	function fetchData($project_task_id) {
-		$res=db_query("SELECT * FROM project_task_vw
-			WHERE project_task_id='$project_task_id'
-			AND group_project_id='". $this->ProjectGroup->getID() ."'");
+		$res = db_query_params ('SELECT * FROM project_task_vw
+			WHERE project_task_id=$1
+			AND group_project_id=$2',
+					array ($project_task_id,
+					       $this->ProjectGroup->getID())) ;
 		if (!$res || db_numrows($res) < 1) {
 			$this->setError('ProjectTask::fetchData() Invalid Task ID'.db_error());
 			return false;
@@ -428,11 +432,14 @@ class ProjectTask extends Error {
 	 *	an id, for example an ID generated by MS Project, which needs to be restored later
 	 */
 	function setExternalID($id) {
-		$res=db_query("UPDATE project_task_external_order SET external_id='$id' 
-			WHERE project_task_id='".$this->getID()."'");
+		$res = db_query_params ('UPDATE project_task_external_order SET external_id=$1
+			WHERE project_task_id=$2',
+					array ($id,
+					       $this->getID())) ;
 		if (db_affected_rows($res) < 1) {
-			$res=db_query("INSERT INTO project_task_external_order (project_task_id,external_id) 
-				VALUES ('".$this->getID()."','$id')");
+			$res = db_query_params ('INSERT INTO project_task_external_order (project_task_id,external_id) VALUES ($1, $2)', 
+						array ($this->getID(),
+						       $id)) ;
 		}
 	}
 
@@ -453,12 +460,13 @@ class ProjectTask extends Error {
 	function getRelatedArtifacts() {
 		if (!$this->relatedartifacts) {
 			$this->relatedartifacts=
-			db_query("SELECT agl.group_id,agl.name,agl.group_artifact_id,a.artifact_id,a.open_date,a.summary 
+				db_query_params ('SELECT agl.group_id,agl.name,agl.group_artifact_id,a.artifact_id,a.open_date,a.summary 
 			FROM artifact_group_list agl, artifact a 
 			WHERE a.group_artifact_id=agl.group_artifact_id
 			AND EXISTS (SELECT artifact_id FROM project_task_artifact 
 				WHERE artifact_id=a.artifact_id
-				AND project_task_id='". $this->getID() ."')");
+				AND project_task_id=$1',
+						 array ($this->getID())) ;
 		}
 		return $this->relatedartifacts;
 	}
@@ -483,8 +491,9 @@ class ProjectTask extends Error {
 			if ($art_array[$i] < 1) {
 				continue;
 			}
-			$res=db_query("INSERT INTO project_task_artifact (project_task_id,artifact_id) 
-				VALUES ('".$this->getID()."','".$art_array[$i]."')");
+			$res = db_query_params ('INSERT INTO project_task_artifact (project_task_id,artifact_id) VALUES ($1,$2)', 
+						array ($this->getID(),
+						       $art_array[$i])) ;
 			if (!$res) {
 				$this->setError('Error inserting artifact relationship: '.db_error());
 				return false;
@@ -506,9 +515,11 @@ class ProjectTask extends Error {
 		}
 
 		for ($i=0; $i<count($art_array); $i++) {
-			$res=db_query("DELETE FROM project_task_artifact
-				WHERE project_task_id='".$this->getID()."'
-				AND artifact_id='".$art_array[$i]."'");
+			$res = db_query_params ('DELETE FROM project_task_artifact
+				WHERE project_task_id=$1
+				AND artifact_id=$2',
+						array ($this->getID(),
+						       $art_array[$i])) ;
 			if (!$res) {
 				$this->setError('Error deleting artifact relationship: '.db_error());
 				return false;
@@ -534,43 +545,50 @@ class ProjectTask extends Error {
 		}
 		db_begin();
 
-		$res = db_query("DELETE FROM project_assigned_to WHERE project_task_id='".$this->getID()."'");
+		$res = db_query_params ('DELETE FROM project_assigned_to WHERE project_task_id=$1',
+					array ($this->getID())) ;
 		if (!$res) {
 			$this->setError('Error deleting assigned users relationship: '.db_error());
 			db_rollback();
 			return false;
 		}
-		$res = db_query("DELETE FROM project_dependencies WHERE project_task_id='".$this->getID()."'");
+		$res = db_query_params ('DELETE FROM project_dependencies WHERE project_task_id=$1',
+					array ($this->getID())) ;
 		if (!$res) {
 			$this->setError('Error deleting dependencies: '.db_error());
 			db_rollback();
 			return false;
 		}
-		$res = db_query("DELETE FROM project_history WHERE project_task_id='".$this->getID()."'");
+		$res = db_query_params ('DELETE FROM project_history WHERE project_task_id=$1',
+					array ($this->getID())) ;
 		if (!$res) {
 			$this->setError('Error deleting history: '.db_error());
 			db_rollback();
 			return false;
 		}
-		$res = db_query("DELETE FROM project_messages WHERE project_task_id='".$this->getID()."'");
+		$res = db_query_params ('DELETE FROM project_messages WHERE project_task_id=$1',
+					array ($this->getID())) ;
 		if (!$res) {
 			$this->setError('Error deleting messages: '.db_error());
 			db_rollback();
 			return false;
 		}
-		$res = db_query("DELETE FROM project_task_artifact	WHERE project_task_id='".$this->getID()."'");
+		$res = db_query_params ('DELETE FROM project_task_artifact WHERE project_task_id=$1',
+					array ($this->getID())) ;
 		if (!$res) {
 			$this->setError('Error deleting artifacts: '.db_error());
 			db_rollback();
 			return false;
 		}
-		$res = db_query("DELETE FROM rep_time_tracking	WHERE project_task_id='".$this->getID()."'");
+		$res = db_query_params ('DELETE FROM rep_time_tracking WHERE project_task_id=$1',
+					array ($this->getID())) ;
 		if (!$res) {
 			$this->setError('Error deleting time tracking report: '.db_error());
 			db_rollback();
 			return false;
 		}
-		$res = db_query("DELETE FROM project_task WHERE project_task_id='".$this->getID()."'");
+		$res = db_query_params ('DELETE FROM project_task WHERE project_task_id=$1',
+					array ($this->getID())) ;
 		if (!$res) {
 			$this->setError('Error deleting task: '.db_error());
 			db_rollback();
@@ -592,15 +610,20 @@ class ProjectTask extends Error {
 		//	May not yet have an ID, if we are creating a NEW task
 		//
 		if ($this->getID()) {
-			$addstr=" AND project_task_id <> '". $this->getID() ."' ";
-		} else {
-			$addstr='';
-		}
-		$sql="SELECT project_task_id,summary 
+			return db_query_params ('SELECT project_task_id,summary 
 		FROM project_task 
-		WHERE group_project_id='". $this->ProjectGroup->getID() ."' 
-		$addstr ORDER BY project_task_id DESC";
-		return db_query($sql);
+		WHERE group_project_id=$1
+		AND project_task_id <> $2
+                ORDER BY project_task_id DESC',
+						array ($this->ProjectGroup->getID(),
+						       $this->getID())) ;
+		} else {
+			return db_query_params ('SELECT project_task_id,summary 
+		FROM project_task 
+		WHERE group_project_id=$1
+		ORDER BY project_task_id DESC',
+						array ($this->ProjectGroup->getID()));
+		}
 	}
 
 	/**
@@ -609,11 +632,11 @@ class ProjectTask extends Error {
 	 *  @return database result set.
 	 */
 	function getHistory() {
-		$sql="SELECT * 
+		return db_query_params ('SELECT * 
 		FROM project_history_user_vw 
-		WHERE project_task_id='". $this->getID() ."' 
-		ORDER BY mod_date DESC";
-		return db_query($sql);
+		WHERE project_task_id=$1
+		ORDER BY mod_date DESC',
+					array ($this->getID())) ;
 	}
 
 	/**
@@ -622,10 +645,11 @@ class ProjectTask extends Error {
 	 *  @return database result set.
 	 */
 	function getMessages() {
-		$sql="select * 
-			FROM project_message_user_vw 
-			WHERE project_task_id='". $this->getID() ."' ORDER BY postdate DESC";
-		return db_query($sql);
+		return db_query_params ('SELECT * 
+		FROM project_message_user_vw 
+		WHERE project_task_id=$1
+		ORDER BY postdate DESC',
+					array ($this->getID())) ;
 	}
 
 	/**
@@ -639,13 +663,17 @@ class ProjectTask extends Error {
 		if ($this->getDetails() == htmlspecialchars($message)) {
 			return true;
 		}
-		$res=db_query("SELECT * FROM project_messages 
-			WHERE project_task_id='".$this->getID()."'
-			AND body='". htmlspecialchars($message) ."'");
+		$res = db_query_params ('SELECT * FROM project_messages 
+			WHERE project_task_id=$1
+			AND body=$2',
+					array ($this->getID(),
+					       htmlspecialchars($message))) ;
 		if (!$res || db_numrows($res) < 1) {
-			$sql="INSERT INTO project_messages (project_task_id,body,posted_by,postdate) 
-				VALUES ('". $this->getID() ."','". htmlspecialchars($message) ."','".user_getid()."','". time() ."')";
-			$res=db_query($sql);
+			$res = db_query_params ('INSERT INTO project_messages (project_task_id,body,posted_by,postdate) VALUES ($1,$2,$3,$4)',
+						array ($this->getID(),
+						       htmlspecialchars($message),
+						       user_getid(),
+						       time())) ;
 			if (!$res || db_affected_rows($res) < 1) {
 				$this->setError('AddMessage():: '.db_error());
 				return false;
@@ -667,7 +695,12 @@ class ProjectTask extends Error {
 	function addHistory ($field_name,$old_value) {
 		$sql="insert into project_history(project_task_id,field_name,old_value,mod_by,mod_date) 
 			VALUES ('". $this->getID() ."','$field_name','$old_value','".user_getid()."','".time()."')";
-		$result=db_query($sql);
+		$result = db_query_params ('INSERT INTO project_history (project_task_id,field_name,old_value,mod_by,mod_date) VALUES ($1,$2,$3,$4,$5)',
+					   array ($this->getID(),
+						  $field_name,
+						  $old_value,
+						  user_getid(),
+						  time())) ;
 		if (!$result) {
 			$this->setError('ERROR IN AUDIT TRAIL - '.db_error());
 			return false;
@@ -692,9 +725,10 @@ class ProjectTask extends Error {
 	 		return false;
 		}
 
-		$res=db_query("SELECT is_dependent_on_task_id AS id 
+		$res = db_query_params ('SELECT is_dependent_on_task_id AS id 
 			FROM project_dependencies 
-			WHERE project_task_id='$depend_on_id'");
+			WHERE project_task_id=$1',
+					array ($depend_on_id)) ;
 		$rows=db_numrows($res);
 
 		for ($i=0; $i<$rows; $i++) {
@@ -729,9 +763,11 @@ class ProjectTask extends Error {
 			$del_arr = array_values (array_diff ($arr2, $arr));
 //echo "del arr: ".print_r($del_arr);
 			for ($i=0; $i<count($del_arr); $i++) {
-				db_query("DELETE FROM project_dependencies 
-					WHERE project_task_id='".$this->getID()."'
-					AND is_dependent_on_task_id='". $del_arr[$i] ."'");
+				db_query_params ('DELETE FROM project_dependencies 
+					WHERE project_task_id=$1
+					AND is_dependent_on_task_id=$2',
+						 array ($this->getID(),
+							$del_arr[$i])) ;
 				if (db_error()) {
 					$this->setError('setDependentOn()-1:: '.db_error());
 					return false;
@@ -748,9 +784,10 @@ class ProjectTask extends Error {
 				if (!$lnk) {
 					$lnk=PM_LINK_DEFAULT;
 				}
-				$sql="INSERT INTO project_dependencies (project_task_id,is_dependent_on_task_id,link_type) 
-					VALUES ('".$this->getID()."','". $add_arr[$i] ."','$lnk')";
-				db_query($sql);
+				db_query_params ('INSERT INTO project_dependencies (project_task_id,is_dependent_on_task_id,link_type) VALUES ($1,$2,$3)',
+						 array ($this->getID(),
+							$add_arr[$i],
+							$lnk)) ;
 				if (db_error()) {
 					$this->setError('setDependentOn()-2:: '.db_error().$sql);
 					return false;
@@ -796,9 +833,10 @@ class ProjectTask extends Error {
 			return $this->dependon;
 		}
 		if (!$this->dependon) {
-			$res=db_query("SELECT is_dependent_on_task_id,link_type
+			$res = db_query_params ('SELECT is_dependent_on_task_id,link_type
 				FROM project_dependencies
-				WHERE project_task_id='".$this->getID()."'");
+				WHERE project_task_id=$1',
+						array ($this->getID())) ;
 			for ($i=0; $i<db_numrows($res); $i++) {
 				$this->dependon[db_result($res,$i,'is_dependent_on_task_id')] = db_result($res,$i,'link_type');
 			}
@@ -828,17 +866,20 @@ class ProjectTask extends Error {
 			$add_arr = array_values(array_diff ($arr, $arr2));
 			$del_arr = array_values(array_diff ($arr2, $arr));
 			for ($i=0; $i<count($del_arr); $i++) {
-				db_query("DELETE FROM project_assigned_to
-					WHERE project_task_id='".$this->getID()."'
-					AND assigned_to_id='". $del_arr[$i] ."'");
+				db_query_params ('DELETE FROM project_assigned_to
+					WHERE project_task_id=$1
+					AND assigned_to_id=$2',
+						 array ($this->getID(),
+							$del_arr[$i])) ;
 				if (db_error()) {
 					$this->setError('setAssignedTo()-1:: '.db_error());
 					return false;
 				}
 			}
 			for ($i=0; $i<count($add_arr); $i++) {
-				db_query("INSERT INTO project_assigned_to (project_task_id,assigned_to_id) 
-					VALUES ('".$this->getID()."','". $add_arr[$i] ."')");
+				db_query_params ('INSERT INTO project_assigned_to (project_task_id,assigned_to_id) VALUES ($1,$2)',
+						 array ($this->getID(),
+							$add_arr[$i])) ;
 				if (db_error()) {
 					$this->setError('setAssignedTo()-2:: '.db_error());
 					return false;
@@ -861,9 +902,8 @@ class ProjectTask extends Error {
 			return $this->assignedto;
 		}
 		if (!$this->assignedto) {
-			$this->assignedto =& util_result_column_to_array(db_query("SELECT assigned_to_id 
-				FROM project_assigned_to 
-				WHERE project_task_id='".$this->getID()."'"));
+			$this->assignedto =& util_result_column_to_array(db_query_params('SELECT assigned_to_id FROM project_assigned_to WHERE project_task_id=$1',
+											 array ($this->getID()))) ;
 		}
 		return $this->assignedto;
 	}
@@ -1035,22 +1075,33 @@ class ProjectTask extends Error {
 			db_rollback();
 			return false;
 		} else {
-			$sql="UPDATE project_task SET
-				summary='".htmlspecialchars($summary)."',
-				priority='$priority',
-				hours='$hours',
-				start_date='$start_date',
-				end_date='$end_date',
-				status_id='$status_id',
-				percent_complete='$percent_complete',
-				category_id='$category_id',
-				group_project_id='$new_group_project_id',
-				duration='$duration',
-				parent_id='$parent_id'
-				WHERE group_project_id='$group_project_id'
-				AND project_task_id='".$this->getID()."'";
-
-			$res=db_query($sql);
+			$res = db_query_params ('UPDATE project_task SET
+				summary=$1,
+				priority=$2,
+				hours=$3,
+				start_date=$4,
+				end_date=$5,
+				status_id=$6,
+				percent_complete=$7,
+				category_id=$8,
+				group_project_id=$9,
+				duration=$10,
+				parent_id=$11
+				WHERE group_project_id=$12
+				AND project_task_id=$13',
+						array (htmlspecialchars($summary),
+						       $priority,
+						       $hours,
+						       $start_date,
+						       $end_date,
+						       $status_id,
+						       $percent_complete,
+						       $category_id,
+						       $new_group_project_id,
+						       $duration,
+						       $parent_id,
+						       $group_project_id,
+						       $this->getID())) ;
 			if (!$res) {
 				$this->setError('Error On ProjectTask::update-5: '.db_error().$sql);
 				db_rollback();
