@@ -10,7 +10,6 @@
  *
  * Geoffrey Herteg, August 29, 2000
  *
- * @version   $Id$
  */
  
 require_once $gfcommon.'include/constants.php';
@@ -53,6 +52,17 @@ class Layout extends Error {
 		$this->Error();
 	}
 
+	/**
+	 *	headerLink() - common code for all themes
+	 *
+	 */
+	function headerLink() {
+		echo '<link rel="alternate" title="'.$GLOBALS['sys_name'].' - Project News Highlights RSS" href="'.util_make_url ('/export/rss_sfnews.php').'" type="application/rss+xml"/>';
+		echo '<link rel="alternate" title="'.$GLOBALS['sys_name'].' - Project News Highlights RSS 2.0" href="'.util_make_url ('/export/rss20_news.php').'" type="application/rss+xml"/>';
+		echo '<link rel="alternate" title="'.$GLOBALS['sys_name'].' - New Projects RSS" href="'.util_make_url ('/export/rss_sfprojects.php').'" type="application/rss+xml"/>';
+		echo '<link rel="search"  title="'.$GLOBALS['sys_name'].'" href="'.util_make_url ('/export/search_plugin.php').'" type="application/opensearchdescription+xml"/>';
+	}
+
 	/**
 	 *	headerStart() - common code for all themes
 	 *
@@ -76,9 +86,7 @@ class Layout extends Error {
   <head>
 	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 	<title><?php echo $params['title']; ?></title>
-	<link rel="alternate" title="<?php echo $GLOBALS['sys_name']; ?> - Project News Highlights RSS" href="<?php echo util_make_url ('/export/rss_sfnews.php'); ?>" type="application/rss+xml"/>
-	<link rel="alternate" title="<?php echo $GLOBALS['sys_name']; ?> - Project News Highlights RSS 2.0" href="<?php echo  util_make_url ('/export/rss20_news.php'); ?>" type="application/rss+xml"/>
-	<link rel="alternate" title="<?php echo $GLOBALS['sys_name']; ?> - New Projects RSS" href="<?php echo util_make_url ('/export/rss_sfprojects.php'); ?>" type="application/rss+xml"/>
+	<?php $this->headerLink(); ?>
 	
 	<?php	if (isset($GLOBALS['group_id'])) { 
 			$activity = '<link rel="alternate" title="' . $GLOBALS['sys_name'] . ' - New Activity RSS" href="'. util_make_url ('/export/rss20_activity.php?group_id='.$GLOBALS['group_id']).'" type="application/rss+xml"/>';
@@ -147,7 +155,8 @@ class Layout extends Error {
 		<td><?php echo $this->searchBox(); ?></td>
 		<td align="right"><?php
 			if (session_loggedin()) {
-				echo util_make_link ('/account/logout.php',_('Log Out'),array('class'=>'lnkutility'));
+				$u =& user_get_object(user_getid());
+				echo util_make_link ('/account/logout.php', sprintf("%s (%s)", _('Log Out'), $u->getRealName()),array('class'=>'lnkutility'));
 				echo util_make_link ('/account/',_('My Account'),array('class'=>'lnkutility'));
 			} else {
 				echo util_make_link ('/account/login.php',_('Log In'),array('class'=>'lnkutility'));
@@ -401,11 +410,11 @@ if (isset($params['group']) && $params['group']) {
 	}
 
 	function outerTabs($params) {
-		global $sys_use_trove,$sys_use_snippet,$sys_use_people;
+		global $sys_use_trove,$sys_use_snippet,$sys_use_people,$sys_use_project_tags, $sys_use_project_full_list;
 
 		$TABS_DIRS[]='/';
 		$TABS_DIRS[]='/my/';
-		if ($sys_use_trove) {
+		if ($sys_use_trove || $sys_use_project_tags || $sys_use_project_full_list) {
 			$TABS_DIRS[]='/softwaremap/';
 		}
 		if ($sys_use_snippet) {
@@ -416,8 +425,8 @@ if (isset($params['group']) && $params['group']) {
 		}
 		$TABS_TITLES[]=_('Home');
 		$TABS_TITLES[]=_('My&nbsp;Page');
-		if ($sys_use_trove) {
-			$TABS_TITLES[]=_('Project&nbsp;Tree');
+		if ($sys_use_trove || $sys_use_project_tags || $sys_use_project_full_list) {
+			$TABS_TITLES[]=_('Projects');
 		}
 		if ($sys_use_snippet) {
 			$TABS_TITLES[]=_('Code&nbsp;Snippets');
@@ -849,6 +858,8 @@ if (isset($params['group']) && $params['group']) {
 	}
 	
 	function createUnderSections($sectionsArray) {
+		global $group_subsection_names;
+
 		$countLines = 0;
 		foreach ($sectionsArray as $section) {
 			if(is_array($section)) {
@@ -1062,7 +1073,7 @@ if (isset($params['group']) && $params['group']) {
 		if (!session_loggedin()) {
 			return '';
 		} else {
-			$res=db_query("SELECT * FROM groups NATURAL JOIN user_group WHERE user_id='".user_getid()."' ORDER BY group_name");
+			$res=db_query("SELECT * FROM groups JOIN user_group USING (group_id) WHERE user_id='".user_getid()."' ORDER BY group_name");
 echo db_error();
 			if (!$res || db_numrows($res) < 1) {
 				return '';
