@@ -113,10 +113,7 @@ class Theme extends Layout {
     <title><?php echo $params['title']; ?></title>
     <link rel="icon" type="image/png" href="<?php echo util_make_url('/images/icon.png'); ?>"/>
     <link rel="shortcut icon" type="image/png" href="<?php echo util_make_url('/images/icon.png'); ?>"/>
-    <link rel="alternate" title="<?php echo $GLOBALS['sys_name']; ?> - Project News Highlights RSS" href="<?php echo util_make_url ('/export/rss_sfnews.php'); ?>" type="application/rss+xml"/>
-    <link rel="alternate" title="<?php echo $GLOBALS['sys_name']; ?> - Project News Highlights RSS" href="<?php echo util_make_url ('/export/rss20_news.php'); ?>" type="application/rss+xml"/>
-    <link rel="alternate" title="<?php echo $GLOBALS['sys_name']; ?> - New Projects RSS" href="<?php echo util_make_url ('/export/rss_sfprojects.php'); ?>" type="application/rss+xml"/>
-
+		<?php $this->headerLink(); ?>
     <script language="JavaScript" type="text/javascript">
     <!--
 
@@ -157,8 +154,9 @@ class Theme extends Layout {
 		  <td class="topLeft"><?php echo util_make_link ('/', html_image('header/top-logo.png',192,54,array('border'=>'0'))); ?></td>
         <td class="middleRight"><?php echo $this->searchBox(); ?></td>
         <td class="middleRight"><?php
-        if (session_loggedin()) {
-        	echo util_make_link ('/account/logout.php', _('Log Out'));
+	if (session_loggedin()) {
+		$u =& user_get_object(user_getid());
+		echo util_make_link ('/account/logout.php', sprintf("%s (%s)", _('Log Out'), $u->getRealName()));
         	echo ' | ';
         	echo util_make_link ('/account/', _('My Account'));
         } else {
@@ -259,7 +257,7 @@ if ($sys_show_source) {
         return '
         <!-- Box Top Start -->
 
-        <table cellspacing="0" cellpadding="0" width="100%" border="0" background="'.$this->imgroot.'vert-grad.png">
+        <table cellspacing="0" cellpadding="0" style="table-layout:fixed" width="100%" border="0" background="'.$this->imgroot.'vert-grad.png">
         <tr align="center">
             <td valign="top" style="text-align:right" width="10" background="'.$this->imgroot.'box-topleft.png"><img src="'.$this->imgroot.'clear.png" width="10" height="20" /></td>
             <td width="100%" background="'.$this->imgroot.'box-grad.png"><span class="titlebar">'.$title.'</span></td>
@@ -362,13 +360,13 @@ if ($sys_show_source) {
     }
 
     function outerTabs($params) {
-        global $sys_use_trove,$sys_use_snippet,$sys_use_people;
+        global $sys_use_trove,$sys_use_snippet,$sys_use_people,$sys_use_project_tags,$sys_use_project_full_list;
 
         $TABS_DIRS[]='/';
         $TABS_DIRS[]='/my/';
-        if ($sys_use_trove) {
-            $TABS_DIRS[]='/softwaremap/';
-        }
+	if ($sys_use_trove || $sys_use_project_tags || $sys_use_project_full_list) {
+        	$TABS_DIRS[]='/softwaremap/';
+	}
         if ($sys_use_snippet) {
             $TABS_DIRS[]='/snippet/';
         }
@@ -377,9 +375,9 @@ if ($sys_show_source) {
         }
         $TABS_TITLES[]=_('Home');
         $TABS_TITLES[]=_('My&nbsp;Page');
-        if ($sys_use_trove) {
-            $TABS_TITLES[]=_('Project&nbsp;Tree');
-        }
+	if ($sys_use_trove || $sys_use_project_tags || $sys_use_project_full_list) {
+        	$TABS_TITLES[]=_('Projects');
+	}
         if ($sys_use_snippet) {
             $TABS_TITLES[]=_('Code&nbsp;Snippets');
         }
